@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """
 wsproto/frame_protocol
-~~~~~~~~~~~~~~
+~~~~~~~~~~~~~~~~~~~~~~
 
 WebSocket frame protocol implementation.
 """
@@ -12,7 +12,7 @@ import struct
 from codecs import getincrementaldecoder
 from collections import namedtuple
 
-from enum import Enum, IntEnum
+from enum import IntEnum
 
 from .compat import unicode, Utf8Validator
 
@@ -59,11 +59,23 @@ class Opcode(IntEnum):
     """
     RFC 6455, Section 5.2 - Base Framing Protocol
     """
+
+    #: Contiuation frame
     CONTINUATION = 0x0
+
+    #: Text message
     TEXT = 0x1
+
+    #: Binary message
     BINARY = 0x2
+
+    #: Close frame
     CLOSE = 0x8
+
+    #: Ping frame
     PING = 0x9
+
+    #: Pong frame
     PONG = 0xA
 
     def iscontrol(self):
@@ -74,19 +86,86 @@ class CloseReason(IntEnum):
     """
     RFC 6455, Section 7.4.1 - Defined Status Codes
     """
+
+    #: indicates a normal closure, meaning that the purpose for
+    #: which the connection was established has been fulfilled.
     NORMAL_CLOSURE = 1000
+
+    #: indicates that an endpoint is "going away", such as a server
+    #: going down or a browser having navigated away from a page.
     GOING_AWAY = 1001
+
+    #: indicates that an endpoint is terminating the connection due
+    #: to a protocol error.
     PROTOCOL_ERROR = 1002
+
+    #: indicates that an endpoint is terminating the connection
+    #: because it has received a type of data it cannot accept (e.g., an
+    #: endpoint that understands only text data MAY send this if it
+    #: receives a binary message).
     UNSUPPORTED_DATA = 1003
+
+    #: Reserved.  The specific meaning might be defined in the future.
+    # DON'T DEFINE THIS: RESERVED_1004 = 1004
+
+    #: is a reserved value and MUST NOT be set as a status code in a
+    #: Close control frame by an endpoint.  It is designated for use in
+    #: applications expecting a status code to indicate that no status
+    #: code was actually present.
     NO_STATUS_RCVD = 1005
+
+    #: is a reserved value and MUST NOT be set as a status code in a
+    #: Close control frame by an endpoint.  It is designated for use in
+    #: applications expecting a status code to indicate that the
+    #: connection was closed abnormally, e.g., without sending or
+    #: receiving a Close control frame.
     ABNORMAL_CLOSURE = 1006
+
+    #: indicates that an endpoint is terminating the connection
+    #: because it has received data within a message that was not
+    #: consistent with the type of the message (e.g., non-UTF-8 [RFC3629]
+    #: data within a text message).
     INVALID_FRAME_PAYLOAD_DATA = 1007
+
+    #: indicates that an endpoint is terminating the connection
+    #: because it has received a message that violates its policy.  This
+    #: is a generic status code that can be returned when there is no
+    #: other more suitable status code (e.g., 1003 or 1009) or if there
+    #: is a need to hide specific details about the policy.
     POLICY_VIOLATION = 1008
+
+    #: indicates that an endpoint is terminating the connection
+    #: because it has received a message that is too big for it to
+    #: process.
     MESSAGE_TOO_BIG = 1009
+
+    #: indicates that an endpoint (client) is terminating the
+    #: connection because it has expected the server to negotiate one or
+    #: more extension, but the server didn't return them in the response
+    #: message of the WebSocket handshake.  The list of extensions that
+    #: are needed SHOULD appear in the /reason/ part of the Close frame.
+    #: Note that this status code is not used by the server, because it
+    #: can fail the WebSocket handshake instead.
     MANDATORY_EXT = 1010
+
+    #: indicates that a server is terminating the connection because
+    #: it encountered an unexpected condition that prevented it from
+    #: fulfilling the request.
     INTERNAL_ERROR = 1011
+
+    #: Server/service is restarting
+    #: (not part of RFC6455)
     SERVICE_RESTART = 1012
+
+    #: Temporary server condition forced blocking client's request
+    #: (not part of RFC6455)
     TRY_AGAIN_LATER = 1013
+
+    #: is a reserved value and MUST NOT be set as a status code in a
+    #: Close control frame by an endpoint.  It is designated for use in
+    #: applications expecting a status code to indicate that the
+    #: connection was closed due to a failure to perform a TLS handshake
+    #: (e.g., the server certificate can't be verified).
     TLS_HANDSHAKE_FAILED = 1015
 
 
@@ -386,12 +465,6 @@ class FrameDecoder(object):
 
 
 class FrameProtocol(object):
-    class State(Enum):
-        HEADER = 1
-        PAYLOAD = 2
-        FRAME_COMPLETE = 3
-        FAILED = 4
-
     def __init__(self, client, extensions):
         self.client = client
         self.extensions = [ext for ext in extensions if ext.enabled()]
@@ -399,7 +472,7 @@ class FrameProtocol(object):
         # Global state
         self._frame_decoder = FrameDecoder(self.client, self.extensions)
         self._message_decoder = MessageDecoder()
-        self._parse_more = self.parse_more_gen()
+        self._parse_more = self._parse_more_gen()
 
         self._outbound_opcode = None
 
@@ -447,7 +520,7 @@ class FrameProtocol(object):
         return Frame(frame.opcode, data, frame.frame_finished,
                      frame.message_finished)
 
-    def parse_more_gen(self):
+    def _parse_more_gen(self):
         # Consume as much as we can from self._buffer, yielding events, and
         # then yield None when we need more data. Or raise ParseFailed.
 
